@@ -1272,6 +1272,8 @@ class DocbookConverter(NodeVisitor):
         elt = SubElement(self.parents_stack[-1], u"para")
         self.insert_ids(node, elt)
         self.insert_classes(node, elt)
+        if node.get(u"pagebreak", u"false").lower() == u'true':
+            elt.set(u"{%s}break" % LDG_NS, u"page")
         self.parents_stack.append(elt)
 
     def depart_paragraph(self, node):
